remap

Function remap 

pub fn remap<F>(outer: &SourceMap, loader: F) -> SourceMap
where F: Fn(&str) -> Option<SourceMap>,
Remap a source map by resolving each source through upstream source maps.

For each source in the outer map, the loader function is called to retrieve the upstream source map. If a source map is returned, mappings are traced through it to the original source. If None is returned, the source is kept as-is.

This is equivalent to @ampproject/remapping in the JS ecosystem.